@@ -8,7 +8,7 @@ from progress.bar import Bar
 from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
 from pyimporters_plugins.base import KnowledgeParserBase, KnowledgeParserOptions, Term, maybe_archive
-from rdflib import Graph, RDF, SKOS
+from rdflib import Graph, RDF, SKOS, URIRef
 from rdflib.resource import Resource
 
 
@@ -26,6 +26,7 @@ class SKOSOptions(KnowledgeParserOptions):
     Options for the RDF knowledge import
     """
     rdf_format: RDFFormat = Query(RDFFormat.xml, description="RDF format")
+    concept_class: str = Query("http://www.w3.org/2004/02/skos/core#Concept", description="")
 
 
 SKOSOptionsModel = SKOSOptions.__pydantic_model__
@@ -42,8 +43,9 @@ class SKOSKnowledgeParser(KnowledgeParserBase):
         with maybe_archive(source, mode=mode) as file:
             thes = g.parse(file=file, format=options.rdf_format)
             bar.next(20)
-            bar.max = len(list(thes.subjects(predicate=RDF.type, object=SKOS.Concept)))
-            for curi in thes[:RDF.type:SKOS.Concept]:
+            concept_class = URIRef(options.concept_class)
+            bar.max = len(list(thes.subjects(predicate=RDF.type, object=concept_class)))
+            for curi in thes[:RDF.type:concept_class]:
                 bar.next()
                 c = Resource(g, curi)
                 concept: Term = None
